<?php //$Id: block_logbook.php,v 1.0 2012-12-30 $


// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Version details
 *
 * @package    block_logbook
 * @copyright  2012 onwards Juli Sargatal Bataller
 * @author     Juli Sargatal Bataller
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


require_once($CFG->dirroot.'/blocks/logbook/lib.php');

// definició de la classe
class block_logbook extends block_base {

    // mètode essencial per a tots els blocks. dóna valors a totes les variables  que s'han d'instanciar
    function init() {
        //títol del block
        $this->title = get_string('pluginname', 'block_logbook');
    }
    
    // mètode que assegura que es carrega un determinat contingut per defecte al block
    public function specialization() {

        // títol
        if (!empty($this->config->title)) {
            $this->title = $this->config->title;
        } else {
            $this->config->title = get_string('pluginname', 'block_logbook');
        }	        
        
        // text visible als alumnes
        if (empty($this->config->text)) {
            $this->config->text = get_string('veureSalts', 'block_logbook');
        }
        
        // text visible als instructors
        if (empty($this->config->text2)) {
            $this->config->text2 = get_string('editarSalts', 'block_logbook');
        }        
    }

   
    // mètode que carrega el contingut que mostrarà el block
    public function get_content() {
    	  global $OUTPUT, $USER, $COURSE, $DB, $PAGE;
    	  
    	      	  
    	  // comprovem si existeix l'objecte que volem utilitzar
        if ($this->content !== null) {
            return $this->content;
        }
     
        // instanciem un objecte de la Classe stdClass
        $this->content         =  new stdClass;
        $this->content->text = '';
        
        
        
        
        	
                   	
        // si l'usuari té el role d'nstructor/professor o superior veurà un text determinat
        // que es pot configurar editant el block
        if(es_professor()){
        	   	
        	   	 $this->content->text .= '<div>';
        	   	 // text per editors
                if (! empty($this->config->text2)) {
                    $this->content->text .= $this->config->text2['text'];
                }
                $this->content->text .= get_string('editarSalts', 'block_logbook');
         
         // si l'usuari NO té el role d'nstructor/professor o superior veurà un altre text
         // que es pot configurar editant el block   
         } else{
            	 $this->content->text .= '<div>';
            	 if (! empty($this->config->text)) {
                    $this->content->text .= $this->config->text1['text'];
                }
                $this->content->text .= get_string('veureSalts', 'block_logbook');

         }
                                
         $this->content->text .=  '<br />';
         
            
			// comprovem si l'usuari actual té role de professor o un de superior
			// si NO el té
		   if(!es_professor()){
					
					 // preparació link per veure, només, Salts de l'alumne actual
					 $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('Salts', 'block_logbook').': '.$USER->lastname.', '.$USER->firstname, 'table_name'=>'block_logbook_salts', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id, 'id_alumne' => $USER->id, 'viewpage' => true));
                $this->content->text .= html_writer::link($url,  $USER->lastname.', '.$USER->firstname);    
                $this->content->text .= '<br />';
         
         // si l'usuari actual té role de professor o un de superior
			} else{
				       
                // llistem tots els alumnes que participen en el curs
                $alumnesCurs=get_enroled_students();
           
                foreach($alumnesCurs as $alumnesCurs){
                	
                	  // preparació link per veure Salts de cada alumne
                    $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('Salts', 'block_logbook').': '.$alumnesCurs->lastname.', '.$alumnesCurs->firstname, 'table_name'=>'block_logbook_salts', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id, 'id_alumne' => $alumnesCurs->id, 'viewpage' => true));
                    $this->content->text .= html_writer::link($url,  $alumnesCurs->lastname.', '.$alumnesCurs->firstname);    
                    $this->content->text .= '<br />'; 
                 
				    }
				
            
        }      	 
        $this->content->text .='</div><br />';  	 
            	   
        
       
        //manteniment taules d'opcions dels salts        
        $this->content->footer = '<br />';
        if (es_professor()) {
            $this->content->footer .= '<div>';
            $this->content->footer .= '<h4>';
            $this->content->footer .= get_string('editarTaules', 'block_logbook');
            $this->content->footer .= '</h4>';
           
            
            // preparació link per veure o editar tipus de salts
            $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('tipusSalts', 'block_logbook'), 'table_name'=>'block_logbook_t_salt', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id,  'viewpage' => true, 'mantenimenttaules' =>true));
            $this->content->footer .= html_writer::link($url,  get_string('tipusSalts', 'block_logbook'));    
            $this->content->footer .= '<br />';
            $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('tipusAvions', 'block_logbook'), 'table_name'=>'block_logbook_t_avio', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id,  'viewpage' => true, 'mantenimenttaules' =>true));
            $this->content->footer .= html_writer::link($url,  get_string('tipusAvions', 'block_logbook'));    
            $this->content->footer .= '<br />';
            $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('tipusParacaigudes', 'block_logbook'), 'table_name'=>'block_logbook_t_paraca', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id,  'viewpage' => true, 'mantenimenttaules' =>true));       
            $this->content->footer .= html_writer::link($url,  get_string('tipusParacaigudes', 'block_logbook'));    
            $this->content->footer .= '<br />';
            $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('tamanysParacaigudes', 'block_logbook'), 'table_name'=>'block_logbook_tam_p', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id,  'viewpage' => true, 'mantenimenttaules' =>true));       
            $this->content->footer .= html_writer::link($url,  get_string('tamanysParacaigudes', 'block_logbook'));    
            $this->content->footer .= '<br />';
            $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('tipusContenidor', 'block_logbook'), 'table_name'=>'block_logbook_t_cont', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id, 'viewpage' => true, 'mantenimenttaules' =>true));       
            $this->content->footer .= html_writer::link($url,  get_string('tipusContenidor', 'block_logbook'));    
            $this->content->footer .= '<br />';     
            $url = new moodle_url('/blocks/logbook/view.php', array('titol' =>get_string('campsExtraAvaluables', 'block_logbook'), 'table_name'=>'block_logbook_camp_e', 'blockid' => $this->instance->id, 'courseid' => $COURSE->id, 'viewpage' => true, 'mantenimenttaules' =>true)); 
            $this->content->footer .= html_writer::link($url,  get_string('campsExtraAvaluables', 'block_logbook'));    
            $this->content->footer .= '<br />';
            $this->content->footer .= '</div>';     
        }
        
 		
        return $this->content;
    }
    
    
    
    
    // mètode que determina si es permet crear múltiples instàncies del mateix block
    public function instance_allow_multiple() {
        return false;
    }
    
    
    
    
    
    // determinació dels entorns on podrà aparèixer el block
    public function applicable_formats() {
        return array(
                 'site-index' => false,
                'course-view' => true, 
        'course-view-social' => false,
                        'mod' => true, 
                  'mod-quiz' => false
         );
     }
  
   
   
   
   // mètode que s'invoca quan s'esborra una instància d'un block.
   // Si es vol que es realizi algun procediment quan s'elimina una instància
   // cal implementar-lo en aquesta funció (per exemple, que s'esborressin les entrades
   // de les taules de la BBDD del block)
    public function instance_delete() {
       
    }
  
 
  
  
}

