<?php


// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Version details
 *
 * @package    block_logbook
 * @copyright  2012 onwards Juli Sargatal Bataller
 * @author     Juli Sargatal Bataller
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


// fitxers dels quals s'utilitzaran determinades funcionalitats
require_once('../../config.php');
require_once($CFG->dirroot.'/blocks/logbook/lib.php');

// paràmetres obligatoris

// id del curs actual 
$courseid = required_param('courseid', PARAM_INT);

// nom de taula de la BBDD amb la qual es vol interactuar
$tablename = required_param('table_name', PARAM_MULTILANG);

// fi paràmetres obligatoris



// paràmetres opcionals

// id d'un registre concret de la taula, si s'escau
$id = optional_param('id', 0, PARAM_INT);

// id de l'alumne amb el qaul s'interactua, si s'escau
$id_alumne = optional_param('id_alumne', 0, PARAM_INT); 

// si confirm és igual a 1, llavors indica que s'ha confirmat l'eliminació del resgistre en qüestió
$confirm = optional_param('confirm', 0, PARAM_INT);

// títol per mostrar de la pàgina actual
$titol = optional_param('titol','no title', PARAM_MULTILANG);

// fi paràmetes opcionals



 
// es requreix que l'usuari estigui logat
require_login($course);

// es requereix que l'usuari tingui permisos per veure la pàgina
require_capability('block/logbook:managepages', context_course::instance($courseid));

 
 

// consulta a la BBDD les dades del curs (registre de la BBDD) en el que s'està treballant
// si no existís es reotrnaria un error
if (!$course = $DB->get_record('course', array('id' => $courseid))) {
    print_error('invalidcourse', 'block_logbook');
}

// consulta a la BBDD les dades del registre amb el què es vol interactuar 
// si no existís es reotrnaria un error
if(! $logbookpage = $DB->get_record($tablename, array('id' => $id))) {
    print_error('invalidid', 'block_logbook');
}
 


// recollim la informació del lloc web i el curs en una variable
$site = get_site();


// establiment de la capçalera per mostrar
$PAGE->set_url('/blocks/logbook/view.php', array('id' => $id, 'courseid' => $courseid));
$heading = $site->fullname . ' :: ' . $course->shortname . ' :: ' .$titol. ' :: table :: ' .$tablename.' :: id :: '. $id;
$PAGE->set_heading($heading);

// fi capçalera



// si NO es rep el paràmetre confirm=1 (no s'ha confirmat l'eliminació del registre)
if (!$confirm) {
	
	// si es rep el paràmetre id_alumne <> 0 (es fa referència a un alumne en concret,
	// per tant, s'està interactuant amb una taula block_logbook_salts)
	if($id_alumne){
	   
	   // preparació de la URL de destinació en cas de CANCEL·LAR l'elimanció del registre
	   $optionsno = redirecciourl('mantenimentTaules', $tablename, $courseid, $blockid, $titol,$id_alumne);
	   
	   // preparació de la URL de destinació en cas de CONFIRMAR l'elimanció del registre
      $optionsyes = new moodle_url('/blocks/logbook/delete.php', array('id_alumne'=>$id_alumne, 'titol'=> $titol, 'id' => $id, 'table_name'=>$tablename, 'courseid' => $courseid, 'confirm' => 1, 'sesskey' => sesskey()));
	
	// si NO es rep el paràmetre id_alumne <> 0 (no es fa referència a cap alumne en concret,
	// per tant, s'està interactuant amb una taula que no és block_logbook_salts)
	}else{
		
		// preparació de la URL de destinació en cas de CANCEL·LAR l'elimanció del registre
		$optionsno = redirecciourl('mantenimentTaules', $tablename, $courseid, $blockid, $titol);
		
		// preparació de la URL de destinació en cas de CONFIRMAR l'elimanció del registre
      $optionsyes = new moodle_url('/blocks/logbook/delete.php', array('titol'=> $titol, 'id' => $id, 'table_name'=>$tablename, 'courseid' => $courseid, 'confirm' => 1, 'sesskey' => sesskey()));
		
	}
    
    // treu per pantalla els botns per confirmar o cancel·lar l'eliminació del registre de la BBDD
    // echo $OUTPUT->confirm(get_string('deletepage', $tablename, $logbookpage->pagetitle), $optionsyes, $optionsno);
    echo $OUTPUT->confirm(get_string('deletepage','block_logbook'), $optionsyes, $optionsno);
    
// si es rep el paràmetre confirm=1 (s'ha confirmat l'eliminació del registre)    
} else {
	
	 // comprovació que la sessió actual sigui vàlida
    if (confirm_sesskey()) {
    	
    	
        // comprovem que el registre que es vol esborrar no s'hagi utilitzat
        // en alguna entrada de les taules de salts (block_logbook_salts) o de avaluacions de camps extra (block_logbook_a_camp)
        // (per preservar la integritat ja que no s'utilitzen Foreign Keys)
    	  if(registreUtilitzat ($tablename, $id)==true){
    	
            print_error('registreUtilitzat', 'block_logbook');
        
        // si el registre en qüestió no està utilitzat es pot eliminar    
        } else {
        	
        	   if (!$DB->delete_records($tablename, array('id' => $id))) {
                print_error('deleteerror', 'block_logbook');    
        	
            }     
               
            // si el que esborrem son entrades a la taula de salts (block_logbook_salts)
            // llavors també esborrem les entrades corresponents a la taula (block_logbook_a_camp)
            if($tablename=='block_logbook_salts'){
            	
            	if (!$DB->delete_records('block_logbook_a_camp', array('id_salt_alumne' => $id))) {
                print_error('deleteerrorCampExtra', 'block_logbook');
                
               }
               
            }
            
        }
        
    // si la sessió no és vàlida treu un error per pantalla
    } else {
    	
        print_error('sessionerror','block_logbook');
        
    }
    
    
    // una vegada esborrat el registre. es redirecciona segons si es tracta d'un salt (id_alumne <> 0) o del manteniment d'una altra taula
    if($id_alumne){
	   
	    redirect(redirecciourl('mantenimentTaules', $tablename, $courseid, $blockid, $titol,$id_alumne));
	   
	 }else{
		
		 redirect(redirecciourl('mantenimentTaules', $tablename, $courseid, $blockid, $titol));
		
	 }
    
}

// treu la capçalera per pantalla
echo $OUTPUT->header();

// treu el peu per pantalla
echo $OUTPUT->footer();