<?php 

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Version details
 *
 * @package    block_logbook
 * @copyright  2012 onwards Juli Sargatal Bataller
 * @author     Juli Sargatal Bataller
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


// determinació de si el role és, com a mínim, de professor no editor (retorna true o false)
function es_professor(){
    
    // objectes globals de Moodle
    global $COURSE;
    	  
    // Comprovació per determinar si l'usuari té els drets en qüestió ('managepages')
    $context = context_course::instance($COURSE->id);        
    $canmanage = has_capability('block/logbook:managepages', $context);    	  
    	
    if($canmanage){
        return true;	
   	}else {
	    return false;
    	}    	
      	
}




// determinació de si el role és, com a mínim, de professor editor (retorna true o false)
function es_professor_editor(){
    
    // objectes globals de Moodle
    global $COURSE;
    	  
    // Comprovació per determinar si l'usuari té els drets en qüestió ('managecourses')
    $context = context_course::instance($COURSE->id);        
    $canmanage = has_capability('block/logbook:managecourses', $context);    	  
    	
    if($canmanage){
        return true;	
   	}else {
	    return false;
    	}    	
     	
}




// llista els alumnes que segueixen el curs (retorna un array amb els camps: lastname, firstname, id)
function get_enroled_students() {
                
    // objectes globals de Moodle
    global $COURSE;
    
    $context = context_course::instance($COURSE->id);
    
    // 5 és número de id pel role 'student' 
    $alumnes= get_role_users(5, $context, false,'u.lastname, u.firstname, u.id','u.lastname ASC');
                  
    return $alumnes;
    
}



// llista els instructors/professors que imparteixen el curs ( retorna un array amb els camps: lastname, firstname i on
// la posició, respectiva a cada professor llistat, dins de l'array és la mateixa que l'id de l'usuari)
function get_enroled_teachers() {
    
    // objectes globals de Moodle            
    global $COURSE;
    
    $context = context_course::instance($COURSE->id);
    
    // els números de role 3, 4 són professor i professor-editor 
    $instr= get_role_users(array(3, 4), $context, false,'u.lastname, u.firstname, u.id','u.lastname ASC');
    
    foreach($instr as $instruc){
    	
    	$instructors[$instruc->id]=$instruc->lastname.', '.$instruc->firstname;
    	
    	
    }   
             
    return $instructors;
    
}



// treu per pantalla (si el paràmetre return és false, com és aquest cas) o retorna (si el paràmetre return és true)
// el que es vol mostrar per pantalla, el qual està contingut a l'array passat per paràmetres ($logbook).
// També es passa per paràmetres el nom de la taula amb la qual es vol interactuar ($tablename), l'id del block ($blockid),
// el títol que es vol mostrar($titol).
function block_logbook_print_page($logbook, $tablename, $blockid, $titol, $return = false) {
    
    // objectes globals de Moodle
    global $OUTPUT, $COURSE;
    
    
    // títol per mostrar
    $display = $OUTPUT->heading($titol);
    
    // recorrem l'array $logbook que hem rebut per paràmetres  
    foreach ($logbook as $logbookpage) {
        	
        // es posa el contingut dins d'un box i aquí obrim el box
        $display .= $OUTPUT->box_start();
            
        // si l'usuari és , com a mínim, professor editor, li proporcionem eines d'edició
        if(es_professor_editor()){
            	
            	// enllaç per editar
               $pageparam = array('titol' =>$titol, 'table_name'=>$tablename, 'blockid' => $blockid->id,'courseid' => $COURSE->id,'id' => $logbookpage->id);
               $editurl = new moodle_url('/blocks/logbook/view.php', $pageparam);
               $editpicurl = new moodle_url('/pix/t/edit.gif');
               $edit = html_writer::link($editurl, html_writer::tag('img', '', array('src' => $editpicurl, 'alt' => get_string('edit'))));
               
               // enllaç per esborrar
               $deleteparam = array('titol' =>$titol, 'id' => $logbookpage->id, 'courseid' => $COURSE->id, 'table_name'=>$tablename);
               $deleteurl = new moodle_url('/blocks/logbook/delete.php', $deleteparam);
               $deletepicurl = new moodle_url('/pix/t/delete.gif');
               $delete = html_writer::link($deleteurl, html_writer::tag('img', '', array('src' => $deletepicurl, 'alt' => get_string('delete'))));
            	
            	$display .= html_writer::start_tag('div');
            	$display .= $edit;
            	
            	// mostrem el botó per esborrar, només, si el registre en qüestió que es vol esborrar no s'hagi utilitzat
               // en alguna entrada de les taules de salts o de avaluacions de camps extra 
               // (per preservar la integritat ja que no s'utilitzen Foreign Keys)
               if(!registreUtilitzat ($tablename, $logbookpage->id)){
               	
                   $display .= $delete;
               	
               }
            	
            	// mostrem l'id de cada registre de l'array
               $display .= clean_text(' (id: ');
               $display .= clean_text($logbookpage->id);
               $display .= clean_text(')');
            	$display .= html_writer::end_tag('div');
            	
            	
        }
            
            // mostrem el contingut de cada registre de l'array
            
            // descripcio del registre
            $display .= html_writer::start_tag('div');
            $display .= html_writer::start_tag('h3');
            $display .= clean_text($logbookpage->descripcio);
            $display .= html_writer::end_tag('h3');
            $display .= html_writer::end_tag('div');
        
            // es mostra si està disponible o no per la seva utilització en l'avaluació de nous salts
            $display .= html_writer::start_tag('div');
            $display .= clean_text(disponible($logbookpage->disponible));
            $display .= html_writer::end_tag('div');
 
            //tanquem el box
            $display .= $OUTPUT->box_end();
        
    }
        
    // si l'usuari és un professor editor pot afegir registres
    if (es_professor_editor()) {
            $pageparam = array('titol' =>$titol, 'table_name'=>$tablename, 'blockid' => $blockid->id, 'courseid' => $COURSE->id,'id' => 0);
            $editurl = new moodle_url('/blocks/logbook/view.php', $pageparam);
            $editpicurl = new moodle_url('/pix/t/add.gif');
            $edit = html_writer::link($editurl, html_writer::tag('img', get_string('afegirRegistre', 'block_logbook').' '.$titol, array('src' => $editpicurl, 'alt' => get_string('add'))));
            $display .= $edit;
          
    }
    	
   
         
    // mirem si retornem el text html o si l'imprimim per pantalla, segons paràmetre return
	 if($return) {
        return $display;
    } else {
        echo $display;
    }
	
	
}




// treu per pantalla (si el paràmetre return és false, com és aquest cas) o retorna (si el paràmetre return és true)
// el que es vol mostrar per pantalla, el qual està contingut a l'array passat per paràmetres ($logbook).
// També es passa per paràmetres el nom de la taula amb la qual es vol interactuar ($tablename), l'id del block ($blockid),
// el títol que es vol mostrar($titol), l'id de l'alumne ($id_alumne), un array amb tots els camps avaluables extra que estan
// disponibles ($totsextracamps), un array amb els camps avaluables extra disponibles que han estat avaluats en el
// salt en qüestió ($logbookextracamps).
function block_logbook_print_page_salts($logbook, $logbookextracamps, $totsextracamps, $tablename, $blockid, $titol, $id_alumne, $return = false) {
    
    // objectes globals de Moodle
    global $OUTPUT, $COURSE,$DB;
    
    // s'instancia un objecte de la Classe stdClass() que servirà per guardar dades dels camps avaluables extra que no han estat 
    // puntuats pel salt en qúestió.
    $dades = new stdClass();
   
    	  // mostrar títol
        $display = $OUTPUT->heading($titol);
        
        // recorrem l'array $logbook que hem rebut per paràmetres  
        foreach ($logbook as $logbookpage) {
        	
            
            
            // posem el contingut dins d'un box i aquí obrim el box
            $display .= $OUTPUT->box_start();
            
            
            
            
            // si l'usuari és , com a mínim, professor, li proporcionem eines d'edició de salts
            if(es_professor()){
            	
            	// enllaç per editar
               $pageparam = array('titol' =>$titol, 'table_name'=>$tablename, 'blockid' => $blockid->id,'courseid' => $COURSE->id,'id' => $logbookpage->id);
               $editurl = new moodle_url('/blocks/logbook/view.php', $pageparam);
               $editpicurl = new moodle_url('/pix/t/edit.gif');
               $edit = html_writer::link($editurl, html_writer::tag('img', '', array('src' => $editpicurl, 'alt' => get_string('edit'))));
               
               // enllaç per esborrar
               $deleteparam = array('id_alumne'=>$id_alumne, 'titol' =>$titol, 'id' => $logbookpage->id, 'courseid' => $COURSE->id, 'table_name'=>$tablename);
               $deleteurl = new moodle_url('/blocks/logbook/delete.php', $deleteparam);
               $deletepicurl = new moodle_url('/pix/t/delete.gif');
               $delete = html_writer::link($deleteurl, html_writer::tag('img', '', array('src' => $deletepicurl, 'alt' => get_string('delete'))));
            	
            	$display .= html_writer::start_tag('div');
            	$display .= $edit;
            	$display .= $delete;
            	
            	// mostrem l'id de cada registre de l'array
               $display .= clean_text(' (id: ');
               $display .= clean_text($logbookpage->id);
               $display .= clean_text(')');
            	$display .= html_writer::end_tag('div');
            	
            }            
         
            
            
            // mostrem el contingut dels registres de las consulta a la BBDD
            
            // número de salt de l'alumne
            $display .= html_writer::start_tag('div');
            $display .= html_writer::start_tag('h3');
            $display .= clean_text(get_string('numSaltAlumne', 'block_logbook').': ');
            $display .= clean_text($logbookpage->num_salt_alumne);
            $display .= html_writer::end_tag('h3');
            $display .= html_writer::end_tag('div');
            
            // tipus de salt  
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('desTipusSalt', 'block_logbook').': ');
            $display .= clean_text($logbookpage->desc_t_salt);
            $display .= html_writer::end_tag('div');
            
            // data i hora del salt           
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('dataHoraSalt', 'block_logbook').': ');
            $display .= userdate($logbookpage->data_hora);
            $display .= html_writer::end_tag('div');
            
            // tipus d'avió utilitzat
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('desTipusAvio', 'block_logbook').': ');
            $display .= clean_text($logbookpage->desc_t_avio);
            $display .= html_writer::end_tag('div');
 
            // contenidor utilitzat
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('desTipusContenidor', 'block_logbook').': ');
            $display .= clean_text($logbookpage->desc_t_cont);
            $display .= html_writer::end_tag('div');
            
            // tipus de paracaigudes principal
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('desTipusParacaPrincipal', 'block_logbook').': ');
            $display .= clean_text($logbookpage->desc_t_paraca);
            $display .= html_writer::end_tag('div');
            
            // tamany paracaigudes principal
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('desTamanyParaca', 'block_logbook').': ');
            $display .= clean_text($logbookpage->desc_tam_p);
            $display .= html_writer::end_tag('div');
            
            // segons de caiguda lliure realitzats en el salt
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('segonsCaigudaLliure', 'block_logbook').': ');
            $display .= clean_text($logbookpage->segons_caiguda_lliure);
            $display .= html_writer::end_tag('div');
            
            // instructor principal
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('instructor1', 'block_logbook').': ');
            $display .= clean_text($logbookpage->cognom_instructor_1);
            $display .= clean_text(', ');
            $display .= clean_text($logbookpage->nom_instuctor_1);
            $display .= html_writer::end_tag('div');
            
            // instructor secundari
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('instructor2', 'block_logbook').': ');
            $display .= clean_text($logbookpage->cognom_instructor_2);
            $display .= clean_text(', ');
            $display .= clean_text($logbookpage->nom_instuctor_2);
            $display .= html_writer::end_tag('div');
            
            // comentaris dels instructors visibles per l'alumne          
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('comentarisPerAlumne', 'block_logbook').': ');
            $display .= $OUTPUT->box_start();  
            $display .= clean_text($logbookpage->comentaris);
            $display .= $OUTPUT->box_end();
            $display .= html_writer::end_tag('div');
            
            // indicació de superació o no superació del nivell
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('aprovaoNo', 'block_logbook').': ');
            $display .= clean_text(superaNivell($logbookpage->supera_nivell));
            $display .= html_writer::end_tag('div');
            
            // instructor que ha realitzat la darrera modificació del registre del salt            
            $display .= html_writer::start_tag('div');
            $display .= clean_text(get_string('instructorUltimaModificacio', 'block_logbook').': ');
            $display .= clean_text($logbookpage->cognom_instructor_mod);
            $display .= clean_text(', ');
            $display .= clean_text($logbookpage->nom_instuctor_mod);
            $display .= html_writer::end_tag('div');
            
            // si l'usuari és , com a mínim, professor, pot veure la informació interna
            if(es_professor()){
            	
            	 $display .= html_writer::start_tag('div');
                $display .= html_writer::start_tag('h3');
                $display .= clean_text(get_string('infoInterna', 'block_logbook'));
                $display .= html_writer::end_tag('h3');
                $display .= html_writer::end_tag('div');
            	 
            	 // comentaris dels instructors només visibles pels instructors        
                $display .= html_writer::start_tag('div');
                $display .= clean_text(get_string('comentarisPerInstructors', 'block_logbook').': ');
                $display .= $OUTPUT->box_start();  
                $display .= clean_text($logbookpage->comentaris_interns);
                $display .= $OUTPUT->box_end();
                $display .= html_writer::end_tag('div');
                
                
       
            	 
                // mostrem els camps avaluables extra que estan actius(disponibles) 
                
                $display .= html_writer::start_tag('div');
                $display .= html_writer::start_tag('h4');
                $display .= clean_text(get_string('campsAvaluablesExtra', 'block_logbook'));
                $display .= html_writer::end_tag('h4');
                $display .= html_writer::end_tag('div');
                
                
                // recorrem l'array que conté tots els camps avaluables extra ques estan disponibles
                foreach ($totsextracamps as $totsextrac) {
                	
                	   // descripció del camp avaluable extra
                	   $display .= html_writer::start_tag('div');
                     $display .= clean_text($totsextrac->descripcio);
                     $display .= clean_text(': ');
                     
                     $trobatCampAvaluat=0;                     
                     
                     // recorrem l'array que conté els camps avaluables extra que estan disponibles 
                     foreach ($logbookextracamps as $logbookextracamp) {
                	   	   
                	   	   
                	   	  // si trobem que el camp ja ha estat avaluat per el salt en qüestió,
                	   	  // es mostra la puntuació assignada, sinó no.
                	  	     if($totsextrac->id==$logbookextracamp->id && $logbookextracamp->id_salt==$logbookpage->id){
                	  	
                     	     $trobatCampAvaluat=1;
                     	     
                     	     $arraiValorsPuntuacio=arrayValoracions();
                     	     
                     	     // es mostra la puntuació que ha estat assignada
                     	     $display .= clean_text($arraiValorsPuntuacio[$logbookextracamp->puntuacio]);
                     	        
                     	        // preparació dels paràmetres per l'enllaç per editar els camps avaluables extra disponibles/actius
                                $pageparam = array('titol' =>$titol, 'table_name'=>'block_logbook_a_camp','id_alumne'=>$id_alumne, 'blockid' => $blockid,'courseid' => $COURSE->id,'id' => $logbookextracamp->id_a_camp);
                                
                     	   
                		     } 
                		     
                     }
                     
                     // si el camp avaluable extra no ha estat puntuat
                     if($trobatCampAvaluat==0){
                     	
                     	  // per defecte, s'assigna el valor 0 a la puntuació del camp avaluable extra que no havia estat
                     	  // puntuat en el salt en qüestió.
                          $dades->id_camp_extra = $totsextrac->id;
                          $dades->id_salt_alumne = $logbookpage->id;
                          $dades->puntuacio = 0;
                     	  
                     	  // s'inserta un nou registre amb el nou camp avaluable extra pel salt en qüestió
                     	  if (!$DB->insert_record('block_logbook_a_camp', $dades)) {
        	
                              print_error('inserterror', 'block_logbook');
            
                          }
                     
                     // recuperem de la BBDD el registre que acabem d'insertar
                     $nouCampExtraEntrat= $DB->get_record('block_logbook_a_camp', array('id_camp_extra' => $dades->id_camp_extra,'id_salt_alumne'=>$dades->id_salt_alumne ));
                     
                     // preparació dels paràmetres per l'enllaç per editar els camps avaluables extra disponibles/actius                     
                     $pageparam = array('titol' =>$titol, 'table_name'=>'block_logbook_a_camp','id_alumne'=>$id_alumne, 'blockid' => $blockid,'courseid' => $COURSE->id,'id' => $nouCampExtraEntrat->id);
                                     
                     }
                     
                     // preparació de la URL per l'enllaç per editar la puntuació del camp avaluable extra en el salt en qüestió
                     $editurl = new moodle_url('/blocks/logbook/view.php', $pageparam);
                     $editpicurl = new moodle_url('/pix/t/edit.gif');
                     $edit = html_writer::link($editurl, html_writer::tag('img', '', array('src' => $editpicurl, 'alt' => get_string('edit'))));

                     $display .= $edit;
                     
                     $display .= html_writer::end_tag('div');
                	   
                }
                
               
                
            }
            
            
            //tanquem el box
            $display .= $OUTPUT->box_end();
        
        }
        
        // si l'usuari és un professor pot afegir salts
         if (es_professor()) {
         	
         	// preparació paràmetres per l'enllaç per insertar un nou salt
            $pageparam = array('id_alumne'=>$id_alumne, 'titol' =>$titol, 'table_name'=>$tablename, 'blockid' => $blockid->id, 'courseid' => $COURSE->id,'id' => 0);
            
            // preparació de la URL de l'enllaç per insertar nous salt per l'alumne
            $editurl = new moodle_url('/blocks/logbook/view.php', $pageparam);
            $editpicurl = new moodle_url('/pix/t/add.gif');
            $edit = html_writer::link($editurl, html_writer::tag('img', get_string('afegirRegistre', 'block_logbook').' '.$titol, array('src' => $editpicurl, 'alt' => get_string('add'))));
            $display .= $edit;
          
        }
    	
   
    
    
    
    
         
    // mirem si retornem el text html o si l'imprimim per pantalla, segons paràmetre return
	 if($return) {
        return $display;
    } else {
        echo $display;
    }
	
	
}










// retorna el text corresponent segons la llengua utilitzada i el valor rebut (1->disponible ó 0->no disponible)
function disponible($disponible) {
	
	if($disponible==1){
	
	    return get_string('disponible', 'block_logbook');
		
	} else{
		
		return get_string('noDisponible', 'block_logbook');
		
	}
	
}



// retorna el text corresponent segons la llengua utilitzada i el valor rebut (1->supera nivell ó 0->no supera nivell)
function superaNivell($superaNivell) {
	
	if($superaNivell==1){
	
	    return get_string('superaNivell', 'block_logbook');
		
	} else{
		
		return get_string('noSuperaNivell', 'block_logbook');
		
	}
	
}



// retorna una URL tenint en compte els paràmetres rebuts.
function redirecciourl($tipusRedireccio, $tablename, $courseid, $blockid, $titol, $id_alumne){
      
      // si es fa referència a un alumne en concret
      if($id_alumne){
      	    			
    		$redireccio=new moodle_url('/blocks/logbook/view.php', array('id_alumne'=>$id_alumne, 'table_name'=>$tablename,'courseid' => $courseid, 'blockid' => $blockid, 'titol' => $titol, 'viewpage' => true, 'mantenimenttaules' => false ));
    	
    	// si es tracta de manteniment de les taules d'opcions dels salts     	
    	} else if($tipusRedireccio=='mantenimentTaules'){
    		
    		$redireccio=new moodle_url('/blocks/logbook/view.php', array( 'table_name'=>$tablename,'courseid' => $courseid, 'blockid' => $blockid, 'titol' => $titol, 'viewpage' => true, 'mantenimenttaules' => true ));
    	
    	// resta de casos	
    	} else {
    		
    		$redireccio=new moodle_url('/course/view.php', array('id' => $courseid));
    		
    	}
    	
    	return $redireccio;

}



// retorna un array amb els registres marcats com a disponibles de la taula passada per paràmetres.
function opcionsArraySelect( $tableName ) {
    
    // objectes globals de Moodle
    global $DB;
        
    
    $array = $DB->get_records($tableName, array('disponible' => 1));
	 foreach($array as $array2){
	 	
	 		$arrayReturn[$array2->id]=$array2->descripcio;
	 		
	 }
    return $arrayReturn;
}





// retorna un array amb les descripcions de les diferents puntuacions possibles dels camps avaluables extra.
function arrayValoracions (){

    $valoracions=array('','< 25%','25% > < 50%','50%','50% > <75%','>75%');

	 return $valoracions;
	 
}


// retorna true ó false depenent de si el camp d'una taula determinada ha estat referenciat o no en una entrada en una altra taula
// i, per tant, es pot determinar si el camp en qüestió pot ser eliminat o no sense comprometre la integritat de la BBDD (Moodle
// no implementa Foreign Keys a la BBDD).
function registreUtilitzat ($tableName, $id){

    // objectes globals de Moodle
    global $DB;
    
    if($tableName=='block_logbook_camp_e'){
	 	
	 	$taulaPerComprovar='block_logbook_a_camp';
	 	$campPerComprovar='id_camp_extra';
	 	
	 }else{
	 	
	 	$taulaPerComprovar='block_logbook_salts';
	 	
	 	if($tableName=='block_logbook_tam_p'){
	 		
	 		 $campPerComprovar='id_tamany_p';
	 		
	 	}else if($tableName=='block_logbook_t_avio'){
	 	
	 	    $campPerComprovar='id_avio';
	 	
	 	}else if($tableName=='block_logbook_t_cont'){
	 	
	 	    $campPerComprovar='id_contenidor';
	 	
	 	}else if($tableName=='block_logbook_t_paraca'){
	 	
	 	    $campPerComprovar='id_paracaigudes_p';
	 	
	 	}else if($tableName=='block_logbook_t_salt'){
	 	
	 	    $campPerComprovar='id_tipus_salt';
	 	
	 	}else if($tableName=='block_logbook_salts'){
	 	
	 	    return false;
	 	
	 	}else{
	 		
	 		return true;
	 		
	 	}
	 	
	 }
    

	 $array = $DB->get_records($taulaPerComprovar, array($campPerComprovar => $id));
	 
	 if($array){
	 	
	 	return true;
	 	
	 }else{
	 	
	 	return false;
	 	
	 }
	 
}



// retorna le descripció del camp avaluable extra del qual es passa l'id que referencia el camp en qüestió
// des de la taula block_logbook_camp_a.
function nomCampExtraAvaluable ( $id ) {
    
    // objectes globals de Moodle
    global $DB;
        
    $sqlparams = array($id);    	
    	
    	      
    $sql = 'SELECT campe.descripcio
    	      FROM {block_logbook_camp_e} campe
    	      INNER JOIN {block_logbook_a_camp} acamp ON campe.id=acamp.id_camp_extra
       	   WHERE acamp.id= ?';
       	   
    	
    $array = $DB->get_records_sql($sql, $sqlparams);
    
	 foreach($array as $array2){
	 	
	 		$descripcio=$array2->descripcio;
	 		
	 }
    return $descripcio;
}



// retorna el número de salt del qual es passa l'id que referencia el salt en qüestió
// des de la taula block_logbook_camp_a.
function capcaleraAvaluacioCampsExtra ( $id ) {
    
    // objectes globals de Moodle
    global $DB;
        
    $sqlparams = array($id);    	
    	
    	      
    $sql = 'SELECT s.num_salt_alumne
    	      FROM {block_logbook_salts} s
    	      INNER JOIN {block_logbook_a_camp} acamp ON s.id=acamp.id_salt_alumne
       	   WHERE acamp.id= ?';
       	   
    	
    $array = $DB->get_records_sql($sql, $sqlparams);
    
	 foreach($array as $array2){
	 	
	 		$descripcio=$array2->num_salt_alumne;
	 		
	 }
    return $descripcio;
}


