<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Version details
 *
 * @package    block_logbook
 * @copyright  2012 onwards Juli Sargatal Bataller
 * @author     Juli Sargatal Bataller
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


require_once("{$CFG->libdir}/formslib.php");
require_once($CFG->dirroot.'/blocks/logbook/lib.php');
 
class logbook_form extends moodleform {
	
	 // variable per determinar la taula amb la què interactuem
	 public $tablename='';
	 
	 // variable per determinar el registre amb el què interactuem
	 public $id='';
	 
	 // variable per poder mostrar, allà on s'escaigui, el títol del formulari
	 public $titol='';
 
    // segons el valor de l'atribut $tablename (nom de la taula amb la què es vol interactuar),
    // es mostra un tipus de formulari o un altre
    function definition() {
        
        // objectes globals de Moodle
        global $USER;
        
        
        
        
        
        // operacions INSERT o UPDATE sobre la taula block_logbook_a_camp
        if($this->tablename=='block_logbook_a_camp'){
        	
        	   $mform =& $this->_form;
        
            // títol del formulari
            $mform->addElement( 'header', get_string('senseTitol', 'block_logbook'),
            get_string('numSaltAlumne', 'block_logbook').': '.capcaleraAvaluacioCampsExtra ( $this->id ) );
            
            
            // puntuació camp extra            
            $mform->addElement( 'select', 'puntuacio', nomCampExtraAvaluable ($this->id).':', arrayValoracions() );
            
            $mform->setType('puntuacio', PARAM_INT);
            $mform->addRule('puntuacio', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // elements-camps ocults
            $mform->addElement('hidden', 'blockid');
            $mform->addElement('hidden', 'courseid');
            $mform->addElement('hidden','id','0');
            $mform->addElement('hidden','id_alumne','0');
            $mform->addElement('hidden','table_name','0');
            $mform->addElement('hidden', 'titol');
            
            // botons de DESAR o CANCEL·LAR
            $this->add_action_buttons();
        
        // operacions INSERT o UPDATE sobre la taula block_logbook_salts    
        }else if($this->tablename=='block_logbook_salts'){
        	
        	   $mform =& $this->_form;
        
            // títol del formulari
            $mform->addElement( 'header', get_string('senseTitol', 'block_logbook'),$this->titol );
            
        	   
            // descripció de l'element
            $mform->addElement('text', 'num_salt_alumne', get_string('numSaltAlumne', 'block_logbook'), 'maxlength="10" size="10"  ');
            $mform->setType('num_salt_alumne', PARAM_INT);
            $mform->addRule('num_salt_alumne', get_string('required', 'block_logbook'), 'required', null, 'client');
            $mform->addRule('num_salt_alumne', get_string('numeric', 'block_logbook'), 'numeric', null, 'client');
            
            // tipus salt            
            $mform->addElement( 'select', 'id_tipus_salt', get_string('desTipusSalt', 'block_logbook').':', opcionsArraySelect('block_logbook_t_salt') );
            $mform->setType('id_tipus_salt', PARAM_INT);
            $mform->addRule('id_tipus_salt', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // data i hora
            $mform->addElement('date_time_selector', 'data_hora', get_string('dataHoraSalt', 'block_logbook'), array('optional' => false));
            $mform->addRule('data_hora', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // tipus avió
            $mform->addElement( 'select', 'id_avio', get_string('desTipusAvio', 'block_logbook').':', opcionsArraySelect('block_logbook_t_avio') );
            $mform->setType('id_avio', PARAM_INT);
            $mform->addRule('id_avio', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // tipus contenidor
            $mform->addElement( 'select', 'id_contenidor', get_string('desTipusContenidor', 'block_logbook').':', opcionsArraySelect('block_logbook_t_cont') );
            $mform->setType('id_contenidor', PARAM_INT);
            $mform->addRule('id_contenidor', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // tipus paracaigudes principal
            $mform->addElement( 'select', 'id_paracaigudes_p', get_string('desTipusParacaPrincipal', 'block_logbook').':', opcionsArraySelect('block_logbook_t_paraca') );
            $mform->setType('id_paracaigudes_p', PARAM_INT);
            $mform->addRule('id_paracaigudes_p', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // tamany paracaigudes principal
            $mform->addElement( 'select', 'id_tamany_p', get_string('desTamanyParaca', 'block_logbook').':', opcionsArraySelect('block_logbook_tam_p') );
            $mform->setType('id_tamany_p', PARAM_INT);
            $mform->addRule('id_tamany_p', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // segons de caiguda lliure del salt
            $mform->addElement('text', 'segons_caiguda_lliure', get_string('segonsCaigudaLliure', 'block_logbook'), 'maxlength="10" size="10" ');
            $mform->setType('segons_caiguda_lliure', PARAM_INT);
            $mform->addRule('segons_caiguda_lliure', get_string('required', 'block_logbook'), 'required', null, 'client');
            $mform->addRule('segons_caiguda_lliure', get_string('numeric', 'block_logbook'), 'numeric', null, 'client');
            
            // instructor primari
            $mform->addElement( 'select', 'id_instructor_1', get_string('instructor1', 'block_logbook').':', get_enroled_teachers() );
            $mform->setType('id_instructor_1', PARAM_INT);
            $mform->addRule('id_instructor_1', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // instructor secundari
            $mform->addElement( 'select', 'id_instructor_2', get_string('instructor2', 'block_logbook').':', get_enroled_teachers() );
            $mform->setType('id_instructor_2', PARAM_INT);
            $mform->addRule('id_instructor_2', null, 'required', null, 'client');
            
            // comentaris que pot veure l'alumne
            $mform->addElement('htmleditor', 'comentaris', get_string('comentarisPerAlumne', 'block_logbook'));
            $mform->setType('comentaris', PARAM_RAW);
            //$mform->addRule('comentaris', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // supera el nivell
            $mform->addElement( 'select', 'supera_nivell', get_string('aprovaoNo', 'block_logbook').':', array(superaNivell(0),superaNivell(1)) );
            $mform->setType('supera_nivell', PARAM_INT);
            $mform->addRule('supera_nivell', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // comentaris interns, bomés per professors/instructors
            $mform->addElement('htmleditor', 'comentaris_interns', get_string('comentarisPerInstructors', 'block_logbook'));
            $mform->setType('comentaris_interns', PARAM_RAW);
            //$mform->addRule('comentaris_interns', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // última modificació per ( id instructor) (camp ocult)
            $mform->addElement('hidden','idInstructorMod', $USER->id);
                      
            // elements-camps ocults
            $mform->addElement('hidden', 'blockid');
            $mform->addElement('hidden', 'courseid');
            $mform->addElement('hidden','id','0');
            $mform->addElement('hidden','id_alumne','0');
            $mform->addElement('hidden','table_name','0');
            $mform->addElement('hidden', 'titol');
            
            // botons de DESAR o CANCEL·LAR
            $this->add_action_buttons();
        
        
        // operacions INSERT o UPDATE sobre la resta de taules del block_logbook
        }else if($this->tablename=='block_logbook_t_salt' || $this->tablename=='block_logbook_t_avio' ||
        $this->tablename=='block_logbook_t_paraca' || $this->tablename=='block_logbook_camp_e' ||
        $this->tablename=='block_logbook_t_cont' || $this->tablename=='block_logbook_tam_p'){
        	
        	
        	   $mform =& $this->_form;
        
            // títol del formulari
            $mform->addElement( 'header', get_string('senseTitol', 'block_logbook'),$this->titol );
            
        	   
        	   
 
            // descripció de l'element
            $mform->addElement('text', 'descripcio', get_string('descripcio', 'block_logbook'));
            $mform->setType('descripcio', PARAM_RAW);
            $mform->addRule('descripcio', get_string('required', 'block_logbook'), 'required', null, 'client');
            
            // camp que indica si aquest registre estarà habilitat o deshabilitat           
            $radioarray=array();
            $radioarray[] =& $mform->createElement('radio', 'disponible', '', get_string('disponible', 'block_logbook'), 1, $attributes);
            $radioarray[] =& $mform->createElement('radio', 'disponible', '', get_string('noDisponible', 'block_logbook'), 0, $attributes);
            $mform->addGroup($radioarray, 'radioar', '', array(' '), false);

        
            
            // elements-camps ocults
            $mform->addElement('hidden', 'blockid');
            $mform->addElement('hidden', 'courseid');
            $mform->addElement('hidden','id','0');
            $mform->addElement('hidden','table_name','0');
            $mform->addElement('hidden', 'titol');
            
            // botons de DESAR o CANCEL·LAR
            $this->add_action_buttons();
        	
        }
        
        
        
    }
}

