<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Version details
 *
 * @package    block_logbook
 * @copyright  2012 onwards Juli Sargatal Bataller
 * @author     Juli Sargatal Bataller
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

 
require_once('../../config.php');
require_once('logbook_form.php');
require_once($CFG->dirroot.'/blocks/logbook/lib.php');

 
global $DB, $OUTPUT, $PAGE, $COURSE, $USER;
 
 
// Cerquem les variables obligatòries

$courseid = required_param('courseid', PARAM_INT);

// recollim l'id de la instància del block
$blockid = required_param('blockid', PARAM_INT);

// recollim el nom de taula de la BBDD
$tablename = required_param('table_name', PARAM_MULTILANG);

// fi vairables/paràmtres obligatoris





// Ara cerquem variables opcionals.

// id del registre de la Base de dades
$id = optional_param('id', 0, PARAM_INT); 

// id de l'alumne
$id_alumne = optional_param('id_alumne', 0, PARAM_INT); 

// 
$viewpage = optional_param('viewpage', false, PARAM_BOOL);

// variable de control per saber si es pretén mantenir taules de la BBDD
$mantenimenttaules =  optional_param('mantenimenttaules', false, PARAM_BOOL);

// títol per mostrar de la pàgina actual
$titol = optional_param('titol','no title', PARAM_MULTILANG);


// fi variables/paràmetres opcionals




// COMPROVACIONS

// comprovem que l'id del curs existeixi 
if (!$course = $DB->get_record('course', array('id' => $courseid))) {
	
    print_error('invalidcourse', 'block_logbook', $courseid);
    
}
 
// es requreix que l'usuari estigui logat
require_login($course);

// es requereix que l'usuari tingui permisos per veure la pàgina
require_capability('block/logbook:viewpages', context_course::instance($COURSE->id));

// FI COMPROVACIONS





// establiment de valors generals a l'objecte global $PAGE
$PAGE->set_url('/blocks/logbook/view.php', array('table_name'=>$tablename,'courseid' => $courseid));
$PAGE->set_pagelayout('standard');
$PAGE->set_heading($titol);



// traiem formulari segons taula i l'id de registre (si s'escau) amb els què volem interactuar 

// instancia de la Classe logbook_form()
$logbook = new logbook_form();

// establiment del valor de l'atribut $tablename de l'objecte creat
$logbook->tablename=$tablename;

// id del registre amb el que es vol interactuar, si s'escau
$logbook->id=$id;

// títol per mostrar
$logbook->titol=$titol;

// crida al mètode que crea el formulari
$logbook->definition();


// paraàmetres que es volen enviar al formulari
$toform['blockid'] = $blockid;
$toform['courseid'] = $courseid;
$toform['id'] = $id;
$toform['id_alumne'] = $id_alumne;
$toform['table_name'] = $tablename;
$toform['titol'] = $titol;

// posem dades al formulari (objecte $logbook de la Classe logbook_form() )
$logbook->set_data($toform);





// en cas de cancel·lar un formulari, es redirigeix cap a la nova URL segons el valor del paràmetres passats 
if($logbook->is_cancelled()) {
    
    redirect(redirecciourl('mantenimentTaules', $tablename, $courseid, $blockid, $titol, $id_alumne));
 
 
 
 
 
 
 
    
// en el cas que el formulari contingui dades per fer un INSERT o un UPDATE    
} else if ($fromform = $logbook->get_data()) {
        
        
        
        
    // posem l'id de l'instructor que realitzat l'última modificació (en el cas del salts) al camp que té el mateix nom que a la BBDD
    $fromform->id_instructor_mod=$fromform->idInstructorMod;
    
    // si es tracte d'una modificació ($id!=0) fem un update, 
    // sinó ($id=0) insertem un registre. En el cas que l'acció corresponent
    // no funcioni traiem error per pantalla.   
    if ($fromform->id != 0) {
    	
        // UPDATE
        if (!$DB->update_record($tablename, $fromform)) {
        	
            print_error('updateerror', 'block_logbook');
            
        }
        
    } else {
    	
        // INSERT
        if (!$DB->insert_record($tablename, $fromform)) {
        	
            print_error('inserterror', 'block_logbook');
            
        }
        
    }
    
    
  
    // en el cas que la taula amb la què s'estigui interactuant sigui 'block_logbook_a_camp', llavors configurem la redirecció
    // posterior passant com a paràmetre $tablename ='block_logbook_salts'
    if($tablename=='block_logbook_a_camp'){
    	
    	  $tablename='block_logbook_salts';
    	  
    }
    
    redirect(redirecciourl('mantenimentTaules', $tablename, $courseid, $blockid, $titol, $id_alumne));









// per la resta de casos, en què no s'ha cancel·lat el formulari i aquest no conté dades (per fer un UPDATE o un INSERT)
} else {
    
    
    
    
    
    // es mostra el títol de la pàgina
    echo $OUTPUT->header();
    
    
    // si s'està realitzant el manteniment de les taules ($mantenimenttaules=true) de les opcions dels salts,
    // es recupera la informació de la BBDD i es mostra per pantalla
    if($mantenimenttaules){
    	
    	  $logbookpage = $DB->get_records($tablename);
    		
    	  block_logbook_print_page($logbookpage, $tablename, $blockid, $titol);
    	  
    	  
    // si hi ha id_alumne!=0	i viewpage=true vol dir que es pretén visualitzar el salts d'un alumne en concret.
    // Per tant, es recupera la informació de la BBDD i es mostra per pantalla.
    } else if ($id_alumne && $viewpage) {	
    	
    	  //  evitem que un usuari alumne pugui veure el salts d'un altre alumne
    	  if(!es_professor()){
    	
    	      $id_alumne=$USER->id;
    	      $titol=$USER->firstname.', '.$USER->lastname;
    	      
    	  }
    	
    	
    	  // fem la consulta dels salts de l'alumne en qüestió
    	
    	  // establiment dels paràmetres de la consulta
    	  $sqlparams = array($id_alumne);
    	
      	// consulta SQL
      	$sql = 'SELECT s.*,
      	 u.firstname AS nom_alumne, u.lastname AS cognom_alumne,
      	 u2.firstname AS nom_instuctor_1, u2.lastname AS cognom_instructor_1,
      	 u3.firstname AS nom_instuctor_2, u3.lastname AS cognom_instructor_2,
      	 u4.firstname AS nom_instuctor_mod, u4.lastname AS cognom_instructor_mod,
      	 ts.descripcio AS desc_t_salt,
      	 ta.descripcio AS desc_t_avio,
      	 tc.descripcio AS desc_t_cont,
      	 tp.descripcio AS desc_t_paraca,
      	 tamp.descripcio AS desc_tam_p
      	 FROM {block_logbook_salts} s
      	 LEFT OUTER JOIN {user} u ON s.id_alumne=u.id
      	 LEFT OUTER JOIN {user} u2 ON s.id_instructor_1=u2.id
      	 LEFT OUTER JOIN {user} u3 ON s.id_instructor_2=u3.id
      	 LEFT OUTER JOIN {user} u4 ON s.id_instructor_mod=u4.id
      	 LEFT OUTER JOIN {block_logbook_t_salt} ts ON s.id_tipus_salt=ts.id
      	 LEFT OUTER JOIN {block_logbook_t_avio} ta ON s.id_avio=ta.id
      	 LEFT OUTER JOIN {block_logbook_t_cont} tc ON s.id_contenidor=tc.id
      	 LEFT OUTER JOIN {block_logbook_t_paraca} tp ON s.id_paracaigudes_p=tp.id
      	 LEFT OUTER JOIN {block_logbook_tam_p} tamp ON s.id_tamany_p=tamp.id
      	 WHERE s.id_alumne= ?
      	 ORDER BY s.num_salt_alumne ASC';

         // execució de la consulta SQL
         $logbookpage = $DB->get_records_sql($sql, $sqlparams);
    	
      	// si l'usuari és professor/instructor (no editor), com a mínim, consultem l'avaluació dels camps avaluables extra
      	if(es_professor()){
      		
    	     	// fem la consulta de l'avaluació dels camps avaluables extra que ja han estat avaluats en els salts de l'alumne
    	     	
    	     	// establiment dels paràmetres de la consulta
    	     	$sqlparams = array($id_alumne, 1);    	
    	
    	      // consulta SQL
    	      $sql = 'SELECT  lace.id AS id_a_camp, lace.puntuacio, campe.id, campe.descripcio, s.id AS id_salt
    	      FROM {block_logbook_camp_e} campe
    	      LEFT OUTER JOIN {block_logbook_a_camp} lace ON campe.id=lace.id_camp_extra
     	      LEFT OUTER JOIN {block_logbook_salts} s ON lace.id_salt_alumne=s.id
      	   LEFT OUTER JOIN {user} u ON s.id_alumne=u.id
       	   WHERE s.id_alumne= ? AND campe.disponible= ?';
       	   
    	      // execució de la consulta SQL
    	      $logbookextracamps = $DB->get_records_sql($sql, $sqlparams);
    	      
    	      
    	      // fem la consulta de l'avaluació del tots els camps avaluables extra, tant si han estat avaluats en
    	      // els salts de l'alumne com si no.
    	      
    	      // establiment dels paràmetres de la consulta
    	      $sqlparams = array(1);   
    	      
    	      // consulta SQL
    	      $sql = 'SELECT  campe.id, campe.descripcio
    	      FROM {block_logbook_camp_e} campe
       	   WHERE campe.disponible= ?';
       	   
       	   $totsextracamps =  $DB->get_records_sql($sql, $sqlparams);
    	     
       	   
    		// si l'usuari NO és professor/instructor (no editor), com a mínim, no es mostren els camps avaluables extra
    		} else {
    		
    	   	$logbookextracamps = '';
    	  
    	   	$totsextracamps = '';
    	   	
      	}
      
    	
    	
      	
    		// es crida la funció que mostra per pantalla els salts de l'alumne
    	   block_logbook_print_page_salts($logbookpage, $logbookextracamps, $totsextracamps, $tablename, $blockid, $titol, $id_alumne);
    	
    	
    	
    // si passem per parametres un 'id' concret vol dir que només volem actuar amb aquest id d'un registre en concret
    // o bé, per visualitzar-lo, o bé, per actualitzar-lo (UPDATE)
    } else if ($id) {
    	
        
        // recuperem la informació de la BBDD referent al registre al què fa referència l'id
        $logbookpage = $DB->get_record($tablename, array('id' => $id));
        
        // si el parametre $viewpage=true es mostra la informació per pantalla
        if($viewpage) {
        	
            block_logbook_print_page($logbookpage, $tablename, $blockid, $titol);
        
        // si el parametre $viewpage=false, llavors, s'actualitza la informació del formulari i es mostra,
        // per pantalla, el formulari del registre en qüestió.
        } else {
        	
            // enviament de dades al formulari (objecte de la Classe logbook_form() )
            $logbook->set_data($logbookpage);
            
            // es mostra el contingut del formulari (objecte de la Classe logbook_form() )
            $logbook->display();
            
        }
     
     
        
    // si $mantenimenttaules=false,
    // si s'ha rebut id_alumne=0 i si NO n'ha s'ha rebut per parametres un 'id' concret, llavors,
    // per defecte, es mostra el formulari (objecte de la Classe logbook_form() ) buit sense valors,
    // el qual permet entrar dades per INSERTAR un nou regsitre a la taula en qüestió ($tablename)
    } else {
    	  
    	  // es mostra el formulari (objecte de la Classe logbook_form() ) per introduir valors per un nou registre
        $logbook->display();
        
    }
    
    
    // es mostra el peu de la pàgina
    echo $OUTPUT->footer();
    
}




